## ADIOS2 plugins examples

The _plugins_ examples are meant to introduce you to the plugin capabilities of ADIOS2, such as
how to develop your own engine or operators.

They can be found in the following subdirectories, and they should be explored in the order that they are listed:

1. [engine](engine): The _engine_ example demonstrates how to develop the read/write capabilities of your ADIOS2 engine
   and use it to read and write variables.
   * Languages: C++
2. [operator](operator): The _operator_ example demonstrates how to read and write variables using the
   ADIOS2/plugins/operators/EncryptionOperator and ADIOS2's BP engine.
   * Languages: C++
